@@ -444,6 +444,7 @@ sqlite_db_disconnect(SV *dbh, imp_dbh_t *imp_dbh)
             sqlite_error(dbh, rc, sqlite3_errmsg(imp_dbh->db));
         }
     }
+    imp_dbh->db = NULL;
 
     av_undef(imp_dbh->functions);
     SvREFCNT_dec(imp_dbh->functions);
@@ -467,7 +468,6 @@ sqlite_db_destroy(SV *dbh, imp_dbh_t *imp_dbh)
     if (DBIc_ACTIVE(imp_dbh)) {
         sqlite_db_disconnect(dbh, imp_dbh);
     }
-    imp_dbh->db = NULL;
 
     DBIc_IMPSET_off(imp_dbh);
 }
@@ -1372,6 +1372,10 @@ sqlite_db_filename(pTHX_ SV *dbh)
     D_imp_dbh(dbh);
     const char *filename;
 
+    if (!imp_dbh->db) {
+        return &PL_sv_undef;
+    }
+
     croak_if_db_is_null();
 
     filename = sqlite3_db_filename(imp_dbh->db, "main");
@@ -1379,19 +1383,19 @@ sqlite_db_filename(pTHX_ SV *dbh)
 }
 
 int
-sqlite_db_busy_timeout(pTHX_ SV *dbh, int timeout )
+sqlite_db_busy_timeout(pTHX_ SV *dbh, SV *timeout )
 {
     D_imp_dbh(dbh);
 
     croak_if_db_is_null();
 
-    if (timeout) {
-        imp_dbh->timeout = timeout;
+    if (timeout && SvIOK(timeout)) {
+        imp_dbh->timeout = SvIV(timeout);
         if (!DBIc_ACTIVE(imp_dbh)) {
             sqlite_error(dbh, -2, "attempt to set busy timeout on inactive database handle");
             return -2;
         }
-        sqlite3_busy_timeout(imp_dbh->db, timeout);
+        sqlite3_busy_timeout(imp_dbh->db, imp_dbh->timeout);
     }
     return imp_dbh->timeout;
 }
